responder

package module
v0.0.0-...-a2d51c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2017 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register(mime string, format string)

'Register' new mime type and format e.g. responder.Register("application/json", "json")

Types

type Responder

type Responder struct {
	// contains filtered or unexported fields
}

'Responder' is holder of registed response handlers, response "Request" based on its accepted mime type

func With

func With(formats interface{}, fc func()) *Responder
	'With' is holder of registed response for mime type formats, the formats could be string or []string
    responder.With("html", func() {
      writer.Write([]byte("this is a html request"))
    }).With([]string{"json", "xml"}, func() {
      writer.Write([]byte("this is a json or xml request"))
    })

func (*Responder) Respond

func (rep *Responder) Respond(request *http.Request)

'Respond' differently according to request's accpeted mime type

func (*Responder) With

func (rep *Responder) With(formats interface{}, fc func()) *Responder

'With' could be used to register response handlerfor mime formats, the formats could be string or []string

Jump to